pub struct FederationDatabase { /* private fields */ }Expand description
Database layer for federation persistence
Implementations
Sourceimpl FederationDatabase
impl FederationDatabase
Sourcepub async fn new(pool: SqlitePool) -> Result<Self>
pub async fn new(pool: SqlitePool) -> Result<Self>
Create a new federation database instance
Errors
This function does not currently return errors but is async for future migration support.
Sourcepub async fn run_migrations(&self) -> Result<()>
pub async fn run_migrations(&self) -> Result<()>
Sourcepub async fn create_federation(&self, federation: &Federation) -> Result<()>
pub async fn create_federation(&self, federation: &Federation) -> Result<()>
Sourcepub async fn get_federation(
&self,
federation_id: &Uuid,
) -> Result<Option<Federation>>
pub async fn get_federation( &self, federation_id: &Uuid, ) -> Result<Option<Federation>>
Sourcepub async fn list_federations(&self, org_id: &Uuid) -> Result<Vec<Federation>>
pub async fn list_federations(&self, org_id: &Uuid) -> Result<Vec<Federation>>
List all federations for an organization
Errors
Returns an error if the database query fails or data parsing fails.
Sourcepub async fn update_federation(&self, federation: &Federation) -> Result<()>
pub async fn update_federation(&self, federation: &Federation) -> Result<()>